# Copyright (c) 2000-2011, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define _with_repolib 1

# If you want repolib package to be built,
# issue the following: 'rpmbuild --with repolib'
%define with_repolib %{?_with_repolib:1}%{!?_with_repolib:0}
%define without_repolib %{!?_with_repolib:1}%{?_with_repolib:0}

%define repodir %{_javadir}/repository.jboss.com/sun-javacc/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define section free
%define _basename javacc

Name:           javacc3
Version:        3.2
Release:        7%{?dist}
Epoch:          0
Summary:        A parser/scanner generator for java
License:        BSD
Source0:        javacc-3.2-src.tar.gz
Source1:        javacc
Source2:        jjdoc
Source3:        jjtree
Source4:        javacc-component-info.xml
Source5:        http://repo2.maven.org/maven2/net/java/dev/javacc/3.2/javacc-3.2.pom
Patch0:         javacc3-build.patch
URL:            https://javacc.dev.java.net/
Group:          Development/Code Generators
BuildRoot:      %{_tmppath}/%{_basename}-%{version}-%{release}-buildroot
BuildArch:      noarch
Requires:       java >= 0:1.6.0
Requires:       jpackage-utils >= 0:1.7.5
BuildRequires:  jpackage-utils >= 0:1.7.5
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  ant >= 0:1.7.1
Requires(post):    jpackage-utils >= 0:1.7.5
Requires(postun):  jpackage-utils >= 0:1.7.5

%description 
Java Compiler Compiler (JavaCC) is the most popular parser generator for use
with Java applications. A parser generator is a tool that reads a grammar
specification and converts it to a Java program that can recognize matches to
the grammar. In addition to the parser generator itself, JavaCC provides other
standard capabilities related to parser generation such as tree building (via
a tool called JJTree included with JavaCC), actions, debugging, etc.

%if %{with_repolib}
%package        repolib
Summary:        Artifacts to be uploaded to a repository library
Group:  Development/Libraries/Java

%description    repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio
%endif

%package manual
Summary:        Manual for %{_basename}
Group:          Development/Documentation

%description manual
%{summary}.

%package demo
Summary:        Examples for %{_basename}
Group:          Development/Documentation

%description demo
%{summary}.

%package javadoc
Summary:        Javadocs for %{_basename}
Group:          Development/Documentation

%description javadoc
%{summary}.

%prep
%setup -q -n %{_basename}-%{version}
%patch0 -b .sav0
cp -p %{SOURCE1} javacc3
cp -p %{SOURCE2} jjdoc3
cp -p %{SOURCE3} jjtree3
mv www/doc .

%build
export CLASSPATH=
export OPT_JAR_LIST=:
ant \
  -Dant.build.javac.source=1.4 \
  -Dversion=%{version} \
  jar javadoc

%install
rm -fr $RPM_BUILD_ROOT
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -m 644 bin/lib/%{_basename}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
ln -s %{name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}.jar
%add_to_maven_depmap %{_basename} %{_basename} %{version} JPP %{name}
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms/
install -m 644 %{SOURCE5} $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-javacc3.pom

install -d -m 755 $RPM_BUILD_ROOT/usr/bin
install -m 755 javacc3 jjdoc3 jjtree3 $RPM_BUILD_ROOT/usr/bin
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/%{name}
cp -pr examples $RPM_BUILD_ROOT%{_datadir}/%{name}
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr dist/javadoc/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

%if %{with_repolib}
install -d -m 755 $RPM_BUILD_ROOT%{repodir}
install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
install -p -m 644 %{SOURCE4} $RPM_BUILD_ROOT%{repodir}/component-info.xml
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" $RPM_BUILD_ROOT%{repodir}/component-info.xml
sed -i "s/@VERSION@/%{version}-brew/g" $RPM_BUILD_ROOT%{repodir}/component-info.xml
install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
cp -p $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar $RPM_BUILD_ROOT%{repodirlib}/javacc.jar
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%{_javadir}/*.jar
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*
%doc LICENSE README
%defattr(0755,root,root,0755)
%{_bindir}/*

%files manual
%defattr(0644,root,root,0755)
%doc doc/*

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}*

%files demo
%defattr(0644,root,root,0755)
%{_datadir}/%{name}

%if %{with_repolib}
%files repolib
%defattr(0644,root,root,0755)
%{_javadir}/repository.jboss.com
%endif

%changelog
* Mon Jan 31 2011 Ralph Apel <r.apel@r-apel.de> 0:3.2-7
- Change the pom, was a relocation only one

* Wed Dec 15 2010 Ralph Apel <r.apel@r-apel.de> 0:3.2-6
- Release for JPP-6
- Add pom and depmap frag
- Add javadocs

* Mon Jan 12 2009 David Walluck <dwalluck@redhat.com> 0:3.2-5
- bump release
- fix repolib

* Fri May 30 2008 Permaine Cheung <pcheung@redhat.com> 0:3.2-2
- First JPP 5 build

* Thu May 01 2008 David Walluck <dwalluck@redhat.com> 0:3.2-2jpp.ep1.5
- build with -Dant.build.javac.source=1.4 to allow enum keyword
- fix missing macros
- fix missing dir ownership
- XXX: where are the javadocs?
- FIXME: need to fix bootstrap (cannot include binary jar)

* Wed Aug 29 2007 Fernando Nasser <fnasser@redhat.com> 0:3.2-2jpp.ep1.4
- Build with repolib subpackage

* Wed Aug 29 2007 Fernando Nasser <fnasser@redhat.com> 0:3.2-2jpp.ep1.2
- Add repolib subpackage
- Add '3' suffix to commands in /usr/bin to avoid conflicts with javacc

* Wed Aug 29 2007 Fernando Nasser <fnasser@redhat.com> 0:3.2-2jpp.ep1.1
- Rebuild

* Mon Apr 24 2006 Fernando Nasser <fnasser@redhat.com> 0:3.2-2jpp_1rh
- First Red Hat build

* Mon Apr 24 2006 Fernando Nasser <fnasser@redhat.com> 0:3.2-2jpp
- Rename to javacc3 as compatibility package
- First JPP 1.7 build

* Mon Nov 22 2004 Fernando Nasser <fnasser@redhat.com> 0:3.2-1jpp_2rh
- Rebuild

* Thu Mar  4 2004 Frank Ch. Eigler <fche@redhat.com> 0:3.2-1jpp_1rh
- RH vacuuming

* Fri Jan 30 2004 Sebastiano Vigna <vigna@acm.org> 0:3.2-1jpp
- First JPackage version
